Example of how to use (and filter on) an association proxy with the SQLAlchemy backend.

For information about association proxies and how to use them, please visit:
http://docs.sqlalchemy.org/en/latest/orm/extensions/associationproxy.html

To run this example:

1. Clone the repository::

    git clone https://github.com/flask-admin/flask-admin.git
    cd flask-admin

2. Create and activate a virtual environment::

    virtualenv env
    source env/bin/activate

3. Install requirements::

    pip install -r 'examples/sqla-association_proxy/requirements.txt'

4. Run the application::

    python examples/sqla-association_proxy/app.py
